@@ -1,22 +1,21 @@
 from flopt import Variable
 
+
 def create_objective(*args, **kwargs):
     def obj(x):
         x1, x2 = x
-        return 0.26*(x1*x1+x2*x2)-0.48*x1*x2
+        return 0.26 * (x1 * x1 + x2 * x2) - 0.48 * x1 * x2
+
     return obj
 
+
 def create_variables(*args, **kwargs):
     variables = [
-        Variable(
-            name=f'x{i}',
-            lowBound=-10,
-            upBound=10,
-            cat='Continuous'
-        )
+        Variable(name=f"x{i}", lowBound=-10, upBound=10, cat="Continuous")
         for i in [0, 1]
     ]
     return variables
 
+
 def minimum_obj(*args, **kwargs):
     return 0
