@@ -3,6 +3,7 @@ from .base_dataset import BaseDataset, BaseInstance
 from datasets.funcLib import benchmark_func
 
 import logging
+
 logger = logging.getLogger(__name__)
 
 
@@ -14,27 +15,24 @@ class FuncDataset(BaseDataset):
     instance_names : list
         instance name list
     """
+
     def __init__(self):
-        self.name = 'func'
+        self.name = "func"
         self.instance_names = list(benchmark_func)
 
-
     def createInstance(self, instance_name):
-        """create FuncInstance
-        """
-        logger.debug(f'{instance_name}')
+        """create FuncInstance"""
+        logger.debug(f"{instance_name}")
         func_data = benchmark_func[instance_name]
-        create_objective = func_data['co']
-        create_variables = func_data['cv']
-        minimum_value    = func_data['mo']
+        create_objective = func_data["co"]
+        create_variables = func_data["cv"]
+        minimum_value = func_data["mo"]
         func_instance = FuncInstance(
-            instance_name, create_objective,
-            create_variables, minimum_value
+            instance_name, create_objective, create_variables, minimum_value
         )
         return func_instance
 
 
-
 class FuncInstance(BaseInstance):
     """Function Benchmark Instance
 
@@ -49,21 +47,18 @@ class FuncInstance(BaseInstance):
     n : int
         dimension (for some instance)
     """
-    def __init__(self, name, create_objective, create_variables,
-            minimum_value, n=10):
+
+    def __init__(self, name, create_objective, create_variables, minimum_value, n=10):
         self.name = name
         self.create_objective = create_objective
         self.create_variables = create_variables
-        self.minimum_value    = minimum_value
+        self.minimum_value = minimum_value
         self.n = n
 
-
     def getBestValue(self):
-        """return the optimal value of objective function
-        """
+        """return the optimal value of objective function"""
         return self.minimum_value(self.n)
 
-
     def createProblem(self, solver):
         """Create problem according to solver
 
@@ -78,13 +73,12 @@ class FuncInstance(BaseInstance):
             if solver can be solve this instance return
             (true, prob formulated according to solver)
         """
-        if 'blackbox' in solver.can_solve_problems:
+        if "blackbox" in solver.can_solve_problems:
             return True, self.createProblemFunc()
         else:
-            logger.info('this instance can be only `blackbox` formulation')
+            logger.info("this instance can be only `blackbox` formulation")
             return False, None
 
-
     def createProblemFunc(self):
         """create problem from instance
 
@@ -98,10 +92,9 @@ class FuncInstance(BaseInstance):
             var.setRandom()
         func = self.create_objective(self.n)
         obj = CustomExpression(lambda *x: func(x), variables)
-        prob = Problem(name='Function:{self.name}')
+        prob = Problem(name="Function:{self.name}")
         prob.setObjective(obj)
         return prob
 
-
     def __str__(self):
-        return f'Instance: {self.name}'
+        return f"Instance: {self.name}"
