@@ -13,7 +13,7 @@ from flopt.env import setup_logger
 logger = setup_logger(__name__)
 
 # instance problems
-tsp_storage = f'{flopt_env.datasets_dir}/tspLib/tsp'
+tsp_storage = f"{flopt_env.datasets_dir}/tspLib/tsp"
 
 
 class TSPDataset(BaseDataset):
@@ -24,15 +24,19 @@ class TSPDataset(BaseDataset):
     instance_names : list
       instance name list
     """
-    def __init__(self):
-        self.name = 'tsp'
-        self.instance_names = [
-            'test8',  'pa561',
-            'gr24',  'pr1002',
-            'fri26', 'fl3795',
-            'gr120', 'rl5915'
-        ]
 
+    def __init__(self):
+        self.name = "tsp"
+        self.instance_names = [
+            "test8",
+            "pa561",
+            "gr24",
+            "pr1002",
+            "fri26",
+            "fl3795",
+            "gr120",
+            "rl5915",
+        ]
 
     def createInstance(self, instance_name):
         """
@@ -41,63 +45,52 @@ class TSPDataset(BaseDataset):
         TSPInstance
         """
 
-        tspfile = f'{tsp_storage}/{instance_name}.tsp'
+        tspfile = f"{tsp_storage}/{instance_name}.tsp"
         return read_instance_file(tspfile)
 
 
-
 def read_instance_file(tspfile):
     name, dimension, D, C = None, None, None, None
 
-    with open(tspfile, 'r') as f:
+    with open(tspfile, "r") as f:
         for line in f:
             line = line.strip()
-            line = line.replace(':', '')
-            if 'NAME' in line:
+            line = line.replace(":", "")
+            if "NAME" in line:
                 name = line.split()[1]
-            if 'TYPE' in line:
+            if "TYPE" in line:
                 pType = line.split()[1]
-            if 'DIMENSION' in line:
+            if "DIMENSION" in line:
                 dimension = int(line.split()[1])
-            if 'EDGE_WEIGHT_TYPE' in line:
+            if "EDGE_WEIGHT_TYPE" in line:
                 edge_weight_type = line.split()[1]
-            if 'EDGE_WEIGHT_FORMAT' in line:
+            if "EDGE_WEIGHT_FORMAT" in line:
                 edge_weight_format = line.split()[1]
-            if 'EDGE_WEIGHT_SECTION' in line:
-                D = read_edge_weight(
-                    f,
-                    edge_weight_format,
-                    dimension
-                )
-            if 'NODE_COORD_SECTION' in line:
-                N, D = read_node_coord(
-                    f,
-                    edge_weight_type,
-                    dimension,
-                    D
-                )
+            if "EDGE_WEIGHT_SECTION" in line:
+                D = read_edge_weight(f, edge_weight_format, dimension)
+            if "NODE_COORD_SECTION" in line:
+                N, D = read_node_coord(f, edge_weight_type, dimension, D)
 
     tsp_instance = TSPInstance(name, dimension, D, C)
     return tsp_instance
 
 
-
 def read_edge_weight(f, edge_weight_format, dim):
     D = np.zeros((dim, dim))
-    if edge_weight_format == 'LOWER_DIAG_ROW':
+    if edge_weight_format == "LOWER_DIAG_ROW":
         i, j = 0, 0
         while i < dim:
             for elm in map(float, f.readline().split()):
                 D[i, j] = D[j, i] = elm
-                (i, j) = (i, j+1) if j < i else (i+1, 0)
+                (i, j) = (i, j + 1) if j < i else (i + 1, 0)
         return D
-    if edge_weight_format == 'FULL_MATRIX':
+    if edge_weight_format == "FULL_MATRIX":
         i, j = 0, 0
         while i < dim:
             for elm in map(float, f.readline().split()):
                 D[i, j] = D[j, i] = elm
                 j = j + 1
-            i, j = i+1, 0
+            i, j = i + 1, 0
         return D
 
 
@@ -108,17 +101,16 @@ def read_node_coord(f, edge_weight_type, dim, D):
         node_ix, x, y = line.split()
         node_ix, x, y = int(node_ix), float(x), float(y)
         N[node_ix] = (x, y)
-    if edge_weight_type == 'EUC_2D':
+    if edge_weight_type == "EUC_2D":
         D = np.zeros((dim, dim))
         for i in range(dim):
             for j in range(dim):
-                ii, jj = N[i+1], N[j+1]
-                dist = math.sqrt((ii[0]-jj[0])**2+(ii[1]-jj[1])**2)
+                ii, jj = N[i + 1], N[j + 1]
+                dist = math.sqrt((ii[0] - jj[0]) ** 2 + (ii[1] - jj[1]) ** 2)
                 D[i, j] = D[j, i] = dist
     return N, D
 
 
-
 class TSPInstance(BaseInstance):
     """TSP Instance
 
@@ -133,6 +125,7 @@ class TSPInstance(BaseInstance):
     C : dict
       node coordinate data
     """
+
     def __init__(self, name, dim, D=None, C=None):
         self.name = name
         self.dim = dim
@@ -140,13 +133,10 @@ class TSPInstance(BaseInstance):
         self.C = C  # Node Coordinate data
         logger.debug(self.__str__(detail=True))
 
-
     def getBestValue(self):
-        """return the optimal value of objective function
-        """
+        """return the optimal value of objective function"""
         return None
 
-
     def createProblem(self, solver):
         """
         Create problem according to solver
@@ -162,41 +152,43 @@ class TSPInstance(BaseInstance):
           if solver can be solve this instance return
           (true, prob formulated according to solver)
         """
-        if 'permutation' in solver.can_solve_problems:
+        if "permutation" in solver.can_solve_problems:
             return True, self.createPermProblem()
-        elif 'lp' in solver.can_solve_problems:
+        elif "lp" in solver.can_solve_problems:
+            if self.dim > 10:
+                logger.info("this instance is enough big not to crate problem")
+                return False, None
             return True, self.createLpProblem()
         else:
-            logger.info('this instance only can be `permutation` formulation')
+            logger.info("this instance only can be `permutation` formulation")
             return False, None
 
-
     def createPermProblem(self):
         # Variables
-        perm = Variable('perm', lowBound=0, upBound=self.dim-1, cat='Permutation')
+        perm = Variable("perm", lowBound=0, upBound=self.dim - 1, cat="Permutation")
 
         # Object
         def tsp_dist(perm):
             distance = 0
-            for head, tail in zip(perm, perm[1:]+[perm[0]]):
+            for head, tail in zip(perm, perm[1:] + [perm[0]]):
                 distance += self.D[head][tail]
             return distance
-        tsp_obj = CustomExpression(func=tsp_dist, variables=[perm])
+
+        tsp_obj = CustomExpression(func=tsp_dist, arg=[perm])
 
         # Problem
-        prob = Problem(name=f'TSP:{self.name}')
+        prob = Problem(name=f"TSP:{self.name}")
         prob += tsp_obj
         return prob
 
-
     def createLpProblem(self):
         # Variables
         cities = list(range(self.dim))
-        x = Variable.matrix('x', len(cities), len(cities), cat='Binary')
+        x = Variable.matrix("x", len(cities), len(cities), cat="Binary")
         np.fill_diagonal(x, Const(0))
 
         # Problem
-        prob = Problem(name=f'TSP(LP):{self.name}')
+        prob = Problem(name=f"TSP(LP):{self.name}")
 
         # Objective
         tsp_obj = Sum(self.D * x)  # sum(D[i, j] * x[i, j] for all i, j)
@@ -208,18 +200,23 @@ class TSPInstance(BaseInstance):
             prob += Sum(x[:, i]) == 1
 
         # Connstants (remove subtour)
-        subsets = [
-            subset for subset in combinations(cities, n_cities)
-            for n_cities in range(2, self.dim-1)
-        ]
-        for subset in tqdm(subsets):
-            prob += Sum(x[subset, subset]) <= n_cities - 1
+        import scipy
+
+        total_subsets = sum(
+            scipy.special.comb(len(cities), r, exact=True)
+            for r in range(2, self.dim - 1)
+        )
+        pbar = tqdm(total=total_subsets, desc="add constraints for removing subtours")
+        for n_cities in range(2, self.dim - 1):
+            for subset in combinations(cities, n_cities):
+                prob += Sum(x[subset, subset]) <= n_cities - 1
+                pbar.update(1)
+        pbar.close()
         return prob
 
-
     def __str__(self, detail=False):
-        s  = f'NAME: {self.name}\n'
-        s += f'DIMENSION: {self.D.shape[0]}'
+        s = f"NAME: {self.name}\n"
+        s += f"DIMENSION: {self.D.shape[0]}"
         if detail:
-            s += f'\nD: {self.D}'
+            s += f"\nD: {self.D}"
         return s
