@@ -1,6 +1,6 @@
 import numpy as np
 
-from flopt.variable import VarElement
+from flopt.variable import VarElement, VariableArray
 from flopt.expression import Expression, Const
 
 
@@ -14,7 +14,10 @@ def Sum(x):
     -------
     all sum of x
     """
-    if isinstance(x, np.ndarray):
+    if isinstance(x, VariableArray):
+        # return x.sum().item()
+        return x.sum_with_divide_and_conquer().item()
+    elif isinstance(x, np.ndarray):
         return x.sum()
     else:
         return sum(x)
@@ -72,8 +75,11 @@ def Value(x):
         cast = type(x)
         return cast([var.value() for var in x])
     elif isinstance(x, np.ndarray):
+
         def to_value(x):
             return x.value()
+
         cast = np.frompyfunc(to_value, 1, 1)
         return cast(x)
-
+    else:
+        return x
